@@ -5,7 +5,7 @@
 %%% Created : 7 Aug 2013 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2017 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2019 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -105,7 +105,10 @@ decode_from_file(File, Opts) ->
 -spec decode(iodata(), options()) -> {ok, term()} | {error, yaml_error()}.
 
 decode(Data, Opts) ->
-    nif_decode(Data, make_flags(Opts)).
+    try nif_decode(Data, make_flags(Opts))
+    catch error:{parser_error, _, _, _} = Reason ->
+	    {error, Reason}
+    end.
 
 -spec encode(term()) -> iolist().
 
